Properties Methods Events Config Options Direct Link

# Class Ext.ux.form.ItemSelector

Package: | Ext.ux.form
Defined In: | ItemSelector.js
Class: | ItemSelector
Extends: | Object

A control that allows selection of between two Ext.ux.form.MultiSelect controls.

## Config Options

Config Options | Defined By
--- | ---
| multiselects : Array An array of Ext.ux.form.MultiSelect config objects, with at least all required parameters (e.g., store) | ItemSelector
| multiselects : Array An array of Ext.ux.form.MultiSelect config objects, with at least all required parameters (e.g., store) | ItemSelector

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| ItemSelector( `Object config` ) Create a new ItemSelector Create a new ItemSelector Parameters: `config` : Object Configuration options Returns: void | ItemSelector
| getLockedCount() : Number Returns the total number of locked columns Returns the total number of locked columns Parameters: None. Returns: `Number` The number of locked columns | ItemSelector
| getTotalLockedWidth() : Number Returns the total width of all locked columns Returns the total width of all locked columns Parameters: None. Returns: `Number` The width of all locked columns | ItemSelector
| isLocked( `Number colIndex` ) : Boolean Returns true if the given column index is currently locked Returns true if the given column index is currently locked Parameters: `colIndex` : Number The column index Returns: `Boolean` True if the column is locked | ItemSelector
| moveColumn( `Number oldIndex`, `Number newIndex` ) : void Moves a column from one position to another Moves a column from one position to another Parameters: `oldIndex` : Number The current column index `newIndex` : Number The destination column index Returns: void | ItemSelector
| setLocked( `Number colIndex`, `Boolean value`, `Boolean suppressEvent` ) : void Locks or unlocks a given column Locks or unlocks a given column Parameters: `colIndex` : Number The column index `value` : Boolean True to lock, false to unlock `suppressEvent` : Boolean Pass false to cause the columnlockchange event not to fire Returns: void | ItemSelector

## Public Events

This class has no public events.